@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010_000;
 
-our $VERSION = '2.029013_002';
+our $VERSION = '2.032000_001';
 use App::Netdisco::Configuration;
 
 use Module::Find ();
@@ -56,9 +56,10 @@ See the demo at: L<http://netdisco2-demo.herokuapp.com/>
 =back
 
 If you have any trouble getting installed or running, check out the
-L<Deployment|App::Netdisco::Manual::Deployment> notes, or speak to someone in
-the C<#netdisco> IRC channel (on freenode).  Before installing or upgrading
-please always review the latest L<Release
+L<Deployment|App::Netdisco::Manual::Deployment> and
+L<Troubleshooting|App::Netdisco::Manual::Troubleshooting> notes, or speak to
+someone in the C<#netdisco> IRC channel (on freenode).  Before installing or
+upgrading please always review the latest L<Release
 Notes|App::Netdisco::Manual::ReleaseNotes>.
 
 =head1 Dependencies
@@ -73,10 +74,11 @@ On Ubuntu/Debian:
 
 On Fedora/Red-Hat:
 
- root:~# yum install perl-core perl-DBD-Pg net-snmp-perl make automake gcc
+ root:~# yum install perl-core perl-DBD-Pg net-snmp-perl net-snmp-devel make automake gcc
 
-With those installed, next check that your system's clock is correct. Then, we
-can proceed...
+On BSD systems please see L<our BSD tips|App::Netdisco::Manual::BSDInstall>.
+
+With those installed, please check that your system's clock is correct.
 
 Create a user on your system called C<netdisco> if one does not already exist.
 We'll install Netdisco and its dependencies into this user's home area, which
@@ -189,7 +191,9 @@ daemon at the same time. Similarly, if you use the device discovery with
 Netdisco 2, disable your system's cron jobs for the Netdisco 1.x poller.
 
 For further documentation on deployment, see
-L<Deployment|App::Netdisco::Manual::Deployment>.
+L<Deployment|App::Netdisco::Manual::Deployment>. If you think Netdisco isn't
+behaving correctly, see also the
+L<Troubleshooting|App::Netdisco::Manual::Troubleshooting> page.
 
 =head1 Upgrading from 2.x
 
@@ -222,11 +226,14 @@ or MAC addreses, VLAN numbers, and so on.
 
 =head2 Command-Line Device and Port Actions
 
-To run a device (discover, etc) or port control job from the command-line, use
-the bundled L<netdisco-do> program. For example:
+Most significant Device jobs and Port actions, as well as several
+troubleshooting and housekeeping duties, can be performed at the command-ling
+with the L<netdisco-do> program. For example:
 
  ~/bin/netdisco-do -D discover -d 192.0.2.1
 
+See the L<netdisco-do documentation|netdisco-do> for further details.
+
 =head2 Import Topology
 
 Netdisco 1.x had support for a topology information file to fill in device
@@ -259,7 +266,7 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
  
-This software is copyright (c) 2012, 2013, 2014 by The Netdisco Developer Team.
+This software is copyright (c) 2012, 2013, 2014, 2015 by The Netdisco Developer Team.
  
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
