@@ -9,7 +9,7 @@ use Role::Tiny;
 use namespace::clean;
 
 # expire devices and nodes according to config
-sub expiry {
+sub expire {
   my ($self, $job) = @_;
 
   if (setting('expire_devices') and setting('expire_devices') > 0) {
@@ -40,6 +40,15 @@ sub expiry {
       });
   }
 
+  if (setting('expire_jobs') and setting('expire_jobs') > 0) {
+      schema('netdisco')->txn_do(sub {
+        schema('netdisco')->resultset('Admin')->search({
+          entered => \[q/< (now() - ?::interval)/,
+              (setting('expire_jobs') * 86400)],
+        })->delete();
+      });
+  }
+
   return job_done("Checked expiry for all Devices and Nodes");
 }
 
